@@ -21,6 +21,10 @@ int main(int argc, char* argv[])
 
     CliController controller;
     const int code = controller.run();
-    Cmd().runAsRoot("/usr/lib/mx-boot-repair/mxbr-lib copy_log", nullptr, nullptr, QuietMode::Yes);
+    if (QFile::exists("/usr/bin/pkexec")) {
+        Cmd().run("pkexec /usr/lib/mx-boot-repair/mxbr-lib copy_log", nullptr, nullptr, QuietMode::Yes);
+    } else {
+        Cmd().runAsRoot("/usr/lib/mx-boot-repair/mxbr-lib copy_log", nullptr, nullptr, QuietMode::Yes);
+    }
     return code;
 }
