@@ -45,7 +45,7 @@
     </message>
     <message>
         <location filename="../src/gui/mainwindow.ui" line="134"/>
-        <location filename="../src/gui/mainwindow.cpp" line="419"/>
+        <location filename="../src/gui/mainwindow.cpp" line="423"/>
         <source>Select Boot Method</source>
         <translation>Selezionare il modo di avvio Boot</translation>
     </message>
@@ -67,7 +67,7 @@
     </message>
     <message>
         <location filename="../src/gui/mainwindow.ui" line="193"/>
-        <location filename="../src/gui/mainwindow.cpp" line="420"/>
+        <location filename="../src/gui/mainwindow.cpp" line="424"/>
         <source>Location:</source>
         <translation>Posizione:</translation>
     </message>
@@ -88,19 +88,19 @@
     </message>
     <message>
         <location filename="../src/gui/mainwindow.ui" line="243"/>
-        <location filename="../src/gui/mainwindow.cpp" line="422"/>
+        <location filename="../src/gui/mainwindow.cpp" line="426"/>
         <source>root</source>
         <translation>root</translation>
     </message>
     <message>
         <location filename="../src/gui/mainwindow.ui" line="278"/>
-        <location filename="../src/gui/mainwindow.cpp" line="427"/>
+        <location filename="../src/gui/mainwindow.cpp" line="431"/>
         <source>Select root location:</source>
         <translation>Seleziona la posizione di root:</translation>
     </message>
     <message>
         <location filename="../src/gui/mainwindow.ui" line="300"/>
-        <location filename="../src/gui/mainwindow.cpp" line="421"/>
+        <location filename="../src/gui/mainwindow.cpp" line="425"/>
         <source>Install on:</source>
         <translation>Installa su:</translation>
     </message>
@@ -151,64 +151,64 @@
     </message>
     <message>
         <location filename="../src/gui/mainwindow.ui" line="521"/>
-        <location filename="../src/gui/mainwindow.cpp" line="78"/>
+        <location filename="../src/gui/mainwindow.cpp" line="82"/>
         <source>Next</source>
         <translation>Successivo</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="455"/>
+        <location filename="../src/gui/mainwindow.cpp" line="459"/>
         <source>Apply</source>
         <translation>Applica</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="98"/>
+        <location filename="../src/gui/mainwindow.cpp" line="102"/>
         <source>GRUB is being installed on %1 device.</source>
         <translation>GRUB è in fase d&apos;installazione sulla periferica %1</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="286"/>
-        <location filename="../src/gui/mainwindow.cpp" line="344"/>
-        <location filename="../src/gui/mainwindow.cpp" line="460"/>
+        <location filename="../src/gui/mainwindow.cpp" line="290"/>
+        <location filename="../src/gui/mainwindow.cpp" line="348"/>
         <location filename="../src/gui/mainwindow.cpp" line="464"/>
-        <location filename="../src/gui/mainwindow.cpp" line="471"/>
-        <location filename="../src/gui/mainwindow.cpp" line="477"/>
-        <location filename="../src/gui/mainwindow.cpp" line="485"/>
-        <location filename="../src/gui/mainwindow.cpp" line="492"/>
+        <location filename="../src/gui/mainwindow.cpp" line="468"/>
+        <location filename="../src/gui/mainwindow.cpp" line="475"/>
+        <location filename="../src/gui/mainwindow.cpp" line="481"/>
+        <location filename="../src/gui/mainwindow.cpp" line="489"/>
+        <location filename="../src/gui/mainwindow.cpp" line="496"/>
         <source>Error</source>
         <translation>Errore</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="136"/>
+        <location filename="../src/gui/mainwindow.cpp" line="140"/>
         <source>The GRUB configuration file (grub.cfg) is being rebuilt.</source>
         <translation>Il file di configurazione di GRUB (grub.cfg) viene ricostituito.</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="170"/>
+        <location filename="../src/gui/mainwindow.cpp" line="174"/>
         <source>Generating initramfs images on: %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="199"/>
+        <location filename="../src/gui/mainwindow.cpp" line="203"/>
         <source>Backing up MBR or PBR from %1 device.</source>
         <translation>Backup dell&apos; MBR o del PBR dall&apos;unità %1.</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="255"/>
+        <location filename="../src/gui/mainwindow.cpp" line="259"/>
         <source>Warning</source>
         <translation>Attenzione</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="256"/>
+        <location filename="../src/gui/mainwindow.cpp" line="260"/>
         <source>You are going to write the content of </source>
         <translation>Stai per scrivere il contenuto di</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="256"/>
+        <location filename="../src/gui/mainwindow.cpp" line="260"/>
         <source> to </source>
         <translation>su</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="257"/>
+        <location filename="../src/gui/mainwindow.cpp" line="261"/>
         <source>
 
 Are you sure?</source>
@@ -217,122 +217,122 @@ Are you sure?</source>
 Sei sicuro?</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="263"/>
+        <location filename="../src/gui/mainwindow.cpp" line="267"/>
         <source>Restoring MBR/PBR from backup to %1 device.</source>
         <translation>Ripristino dell&apos; MBR/PBR da backup sull&apos;unità %1</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="287"/>
+        <location filename="../src/gui/mainwindow.cpp" line="291"/>
         <source>Could not find EFI system partition (ESP) on any system disks. Please create an ESP and try again.</source>
         <translation>Non si riesce a trovare EFI system partition (ESP) su un qualsiasi disco di sistema. Prego, create un ESP e provate ancora.</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="299"/>
+        <location filename="../src/gui/mainwindow.cpp" line="303"/>
         <source>Select %1 location:</source>
         <translation>Seleziona %1 posizione:</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="322"/>
+        <location filename="../src/gui/mainwindow.cpp" line="326"/>
         <source>Back</source>
         <translation>Indietro</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="338"/>
+        <location filename="../src/gui/mainwindow.cpp" line="342"/>
         <source>Success</source>
         <translation>Operazione riuscita</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="338"/>
+        <location filename="../src/gui/mainwindow.cpp" line="342"/>
         <source>Process finished with success.&lt;p&gt;&lt;b&gt;Do you want to exit MX Boot Repair?&lt;/b&gt;</source>
         <translation>Processo ultimato con successo.&lt;p&gt;&lt;b&gt;Vuoi uscire da MX Ripara Boot?&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="344"/>
+        <location filename="../src/gui/mainwindow.cpp" line="348"/>
         <source>Process finished. Errors have occurred.</source>
         <translation>Processo ultimato. Sono incorsi degli errori.</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="105"/>
-        <location filename="../src/gui/mainwindow.cpp" line="144"/>
-        <location filename="../src/gui/mainwindow.cpp" line="176"/>
+        <location filename="../src/gui/mainwindow.cpp" line="109"/>
+        <location filename="../src/gui/mainwindow.cpp" line="148"/>
+        <location filename="../src/gui/mainwindow.cpp" line="180"/>
         <source>Enter password to unlock %1 encrypted partition:</source>
         <translation>Digita la password per sbloccare la partizione criptata:</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="426"/>
+        <location filename="../src/gui/mainwindow.cpp" line="430"/>
         <source>Select GRUB location</source>
         <translation>Seleziona la posizione di GRUB</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="435"/>
+        <location filename="../src/gui/mainwindow.cpp" line="439"/>
         <source>Select initramfs options</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="445"/>
+        <location filename="../src/gui/mainwindow.cpp" line="449"/>
         <source>Select Item to Back Up</source>
         <translation>Seleziona l&apos;elemento da sottoporre a backup</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="450"/>
+        <location filename="../src/gui/mainwindow.cpp" line="454"/>
         <source>Select Item to Restore</source>
         <translation>Seleziona l&apos;elemento da ripristinare</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="460"/>
-        <location filename="../src/gui/mainwindow.cpp" line="471"/>
+        <location filename="../src/gui/mainwindow.cpp" line="464"/>
+        <location filename="../src/gui/mainwindow.cpp" line="475"/>
         <source>No location was selected.</source>
         <translation>Non è stata selezionata nessuna posizione.</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="465"/>
-        <location filename="../src/gui/mainwindow.cpp" line="478"/>
+        <location filename="../src/gui/mainwindow.cpp" line="469"/>
+        <location filename="../src/gui/mainwindow.cpp" line="482"/>
         <source>Please select the root partition of the system you want to fix.</source>
         <translation>Seleziona la partizione di root del sistema che vuoi correggere.</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="483"/>
+        <location filename="../src/gui/mainwindow.cpp" line="487"/>
         <source>Select backup file name</source>
         <translation>Scegli un nome per il file di backup</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="485"/>
-        <location filename="../src/gui/mainwindow.cpp" line="492"/>
+        <location filename="../src/gui/mainwindow.cpp" line="489"/>
+        <location filename="../src/gui/mainwindow.cpp" line="496"/>
         <source>No file was selected.</source>
         <translation>Nessun file è stato scelto</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="490"/>
+        <location filename="../src/gui/mainwindow.cpp" line="494"/>
         <source>Select MBR or PBR backup file</source>
         <translation>Scegli il file di backup di MBR o PBR</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="508"/>
+        <location filename="../src/gui/mainwindow.cpp" line="512"/>
         <source>About %1</source>
         <translation>Circa %1</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="510"/>
+        <location filename="../src/gui/mainwindow.cpp" line="514"/>
         <source>Version: </source>
         <translation>Versione: </translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="511"/>
+        <location filename="../src/gui/mainwindow.cpp" line="515"/>
         <source>Simple boot repair program for MX Linux</source>
         <translation>Programma di MX Linux per la riparazione del boot, di facile uso</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="513"/>
+        <location filename="../src/gui/mainwindow.cpp" line="517"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Copyright (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="514"/>
+        <location filename="../src/gui/mainwindow.cpp" line="518"/>
         <source>%1 License</source>
         <translation>%1 Licenza</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow.cpp" line="527"/>
+        <location filename="../src/gui/mainwindow.cpp" line="531"/>
         <source>%1 Help</source>
         <translation>%1 Aiuto</translation>
     </message>
@@ -361,17 +361,93 @@ Sei sicuro?</translation>
         <translation>&amp;Chiudi</translation>
     </message>
     <message>
-        <location filename="../src/gui/main.cpp" line="74"/>
+        <location filename="../src/gui/main.cpp" line="86"/>
         <source>MX Boot Repair</source>
         <translation>MX Ripara Boot</translation>
     </message>
     <message>
-        <location filename="../src/gui/main.cpp" line="82"/>
+        <location filename="../src/gui/main.cpp" line="94"/>
+        <source>MX Boot Repair - GUI and CLI tool for repairing GRUB bootloader</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/gui/main.cpp" line="99"/>
+        <source>Force CLI mode</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/gui/main.cpp" line="100"/>
+        <source>Print actions without executing</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/gui/main.cpp" line="101"/>
+        <source>Do not prompt; require flags</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/gui/main.cpp" line="102"/>
+        <source>Action: install, repair, initramfs, backup, restore</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/gui/main.cpp" line="103"/>
+        <source>Target for install: mbr, esp, root</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/gui/main.cpp" line="104"/>
+        <source>Device for target (e.g., sda, sda1)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/gui/main.cpp" line="105"/>
+        <source>Root partition (e.g., /dev/sda2)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/gui/main.cpp" line="106"/>
+        <source>Partition to mount at /boot in chroot</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/gui/main.cpp" line="107"/>
+        <source>Partition to mount at /boot/efi in chroot</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/gui/main.cpp" line="108"/>
+        <source>Path for backup/restore image</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/gui/main.cpp" line="109"/>
+        <source>Skip confirmations (for restore)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/gui/main.cpp" line="110"/>
+        <source>Enable verbose output</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/gui/main.cpp" line="111"/>
+        <source>Suppress non-error output</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/gui/main.cpp" line="121"/>
+        <source>Error: --verbose and --quiet options are mutually exclusive
+</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/gui/main.cpp" line="127"/>
         <source>Error</source>
         <translation>Errore</translation>
     </message>
     <message>
-        <location filename="../src/gui/main.cpp" line="83"/>
+        <location filename="../src/gui/main.cpp" line="128"/>
         <source>You must run this program with admin access.</source>
         <translation>Devi eseguire questo programma come amministratore.</translation>
     </message>
@@ -386,148 +462,148 @@ Sei sicuro?</translation>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/cli/controller.cpp" line="157"/>
+        <location filename="../src/cli/controller.cpp" line="234"/>
         <source>MX Boot Repair (CLI)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/cli/controller.cpp" line="158"/>
+        <location filename="../src/cli/controller.cpp" line="235"/>
         <source>1) Install GRUB</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/cli/controller.cpp" line="159"/>
+        <location filename="../src/cli/controller.cpp" line="236"/>
         <source>2) Repair GRUB (update-grub)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/cli/controller.cpp" line="160"/>
+        <location filename="../src/cli/controller.cpp" line="237"/>
         <source>3) Regenerate initramfs</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/cli/controller.cpp" line="161"/>
+        <location filename="../src/cli/controller.cpp" line="238"/>
         <source>4) Backup MBR/PBR</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/cli/controller.cpp" line="162"/>
+        <location filename="../src/cli/controller.cpp" line="239"/>
         <source>5) Restore MBR/PBR</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/cli/controller.cpp" line="163"/>
+        <location filename="../src/cli/controller.cpp" line="240"/>
         <source>q) Quit</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/cli/controller.cpp" line="164"/>
+        <location filename="../src/cli/controller.cpp" line="241"/>
         <source>Select action [1-5 or &apos;q&apos; to quit]: </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/cli/controller.cpp" line="170"/>
+        <location filename="../src/cli/controller.cpp" line="247"/>
         <source>Invalid selection. Enter 1-5 or &apos;q&apos; to quit.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/cli/controller.cpp" line="175"/>
+        <location filename="../src/cli/controller.cpp" line="252"/>
         <source>Target: 0) MBR  1) ESP  2) Root</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/cli/controller.cpp" line="176"/>
+        <location filename="../src/cli/controller.cpp" line="253"/>
         <source>Select target</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/cli/controller.cpp" line="182"/>
-        <location filename="../src/cli/controller.cpp" line="217"/>
-        <location filename="../src/cli/controller.cpp" line="230"/>
+        <location filename="../src/cli/controller.cpp" line="259"/>
+        <location filename="../src/cli/controller.cpp" line="294"/>
+        <location filename="../src/cli/controller.cpp" line="307"/>
         <source>No partitions found. Returning to main menu.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/cli/controller.cpp" line="186"/>
-        <location filename="../src/cli/controller.cpp" line="243"/>
-        <location filename="../src/cli/controller.cpp" line="261"/>
+        <location filename="../src/cli/controller.cpp" line="263"/>
+        <location filename="../src/cli/controller.cpp" line="320"/>
+        <location filename="../src/cli/controller.cpp" line="338"/>
         <source>No disks found. Returning to main menu.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/cli/controller.cpp" line="191"/>
+        <location filename="../src/cli/controller.cpp" line="268"/>
         <source>Select disk for MBR (e.g., sda)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/cli/controller.cpp" line="195"/>
+        <location filename="../src/cli/controller.cpp" line="272"/>
         <source>Select partition for GRUB (e.g., sda1)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/cli/controller.cpp" line="200"/>
+        <location filename="../src/cli/controller.cpp" line="277"/>
         <source>Select root partition of installed system</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/cli/controller.cpp" line="218"/>
+        <location filename="../src/cli/controller.cpp" line="295"/>
         <source>Select root partition to repair</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/cli/controller.cpp" line="231"/>
+        <location filename="../src/cli/controller.cpp" line="308"/>
         <source>Select root partition to regenerate initramfs</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/cli/controller.cpp" line="244"/>
+        <location filename="../src/cli/controller.cpp" line="321"/>
         <source>Select disk to back up MBR/PBR from</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/cli/controller.cpp" line="247"/>
+        <location filename="../src/cli/controller.cpp" line="324"/>
         <source>Output file path (or &apos;b&apos; to go back, &apos;q&apos; to quit): </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/cli/controller.cpp" line="262"/>
+        <location filename="../src/cli/controller.cpp" line="339"/>
         <source>Select disk to restore MBR/PBR to</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/cli/controller.cpp" line="265"/>
+        <location filename="../src/cli/controller.cpp" line="342"/>
         <source>Input backup file path (or &apos;b&apos; to go back, &apos;q&apos; to quit): </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/cli/controller.cpp" line="272"/>
+        <location filename="../src/cli/controller.cpp" line="349"/>
         <source>WARNING: This will overwrite the first 446 bytes of /dev/</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/cli/controller.cpp" line="272"/>
+        <location filename="../src/cli/controller.cpp" line="349"/>
         <source>. Continue? [y/N]: </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/cli/controller.cpp" line="275"/>
+        <location filename="../src/cli/controller.cpp" line="352"/>
         <source>yes</source>
         <comment>confirmation input: full word</comment>
         <translation>sì</translation>
     </message>
     <message>
-        <location filename="../src/cli/controller.cpp" line="276"/>
+        <location filename="../src/cli/controller.cpp" line="353"/>
         <source>y</source>
         <comment>confirmation input: single-letter yes</comment>
         <translation>s</translation>
     </message>
     <message>
-        <location filename="../src/cli/controller.cpp" line="280"/>
+        <location filename="../src/cli/controller.cpp" line="357"/>
         <source>Cancelled.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/cli/controller.cpp" line="287"/>
+        <location filename="../src/cli/controller.cpp" line="364"/>
         <source>Unknown selection</source>
         <translation type="unfinished"></translation>
     </message>
